@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importwizarddisplayinfo.h"
@@ -86,11 +73,11 @@ void ImportWizardDisplayInfo::filterImportInfo(const QString &log)
 
 void ImportWizardDisplayInfo::initializeFilter(MailImporter::Filter &filter)
 {
-    MailImporter::FilterInfo *info = new MailImporter::FilterInfo();
-    ImportFilterInfoGui *infoGui = new ImportFilterInfoGui(mImportWizard->importMailPage());
+    auto *info = new MailImporter::FilterInfo();
+    auto *infoGui = new ImportFilterInfoGui(mImportWizard->importMailPage());
     info->setFilterInfoGui(infoGui);
     info->clear(); // Clear info from last time
-    MailImporter::FilterImporterAkonadi *filterImporter = new MailImporter::FilterImporterAkonadi(info);
+    auto *filterImporter = new MailImporter::FilterImporterAkonadi(info);
     filterImporter->setRootCollection(mImportWizard->importMailPage()->selectedCollection());
     filter.setFilterImporter(filterImporter);
     filter.setFilterInfo(info);
